.. _kemmering_api:

:mod:`kemmering` API
====================

.. automodule:: kemmering

.. autoclass:: tag

.. autoclass:: notag

.. autoclass:: defer

.. autofunction:: bind

Template Helpers
----------------

.. autoclass:: from_context

.. autoclass:: in_context

.. autoclass:: format_context

.. autoclass:: cond

.. autoclass:: loop

:mod:`kemmering.html` API
=========================

.. automodule:: kemmering.html
   :members:

